{% extends 'booking/user/base.html' %}
{% load static %}

{% block side_text %}
    <div class="booking-cta">
        <h1>{{title}}</h1>
        <p>{{description}}</p>
    </div>
{% endblock side_text %}

{% block steps %}
    <!-- Last Step START -->
    <div class="tab-pane fade show active" id="pills-done" role="tabpanel" aria-labelledby="pills-done-tab">
        <h1 class="text-success h2">Your Booking Created!</h1>
        <p class="text-muted">you will get a confirmation email soon.</p>
        <p class="text-muted">thanks for your time!</p>
        <div class="d-flex align-items-center text-center justify-content-center py-3 border">
            <h4 class="text-muted">Booking ID: </h4>
            <h2 style="padding-left: 6px;">#{{booking_id}}</h2>
        </div>
    </div>
    <!-- Last Step END -->
{% endblock steps %}


{% block buttons %}
<div class="form-btn d-flex mt-4">
    <a href="{% url 'create_booking' %}" id="make-new-app" class="btn btn-primary mx-auto">Make another booking</a>
</div>
{% endblock buttons %}
